notetools.make_repeated_notes_from_time_signature
=================================================

.. autofunction:: abjad.tools.notetools.make_repeated_notes_from_time_signature.make_repeated_notes_from_time_signature
